@@ -61,7 +61,8 @@ class VNFManagerTab(tabs.TableTab):
                                      vim,
                                      vnf['status'],
                                      vnf['status'],
-                                     vnf['id'])
+                                     vnf['id'],
+                                     vnf['error_reason'])
                 VNFManagerItemList.add_item(obj)
             return VNFManagerItemList.VNFLIST_P
         except Exception:
@@ -76,3 +77,18 @@ class VNFManagerTabs(tabs.TabGroup):
     slug = "vnfmanager_tabs"
     tabs = (VNFManagerTab,)
     sticky = True
+
+
+class VDUDetailTab(tabs.Tab):
+    name = _("VDU Detail")
+    slug = "VDU_Details"
+    template_name = "nfv/vnfmanager/vdu_details.html"
+
+    def get_context_data(self, request):
+        return {'vnf': self.tab_group.kwargs['vnf']}
+
+
+class VNFDetailsTabs(tabs.TabGroup):
+    slug = "VNF_details"
+    tabs = (VDUDetailTab,)
+    sticky = True
